==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProbeBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ProbeFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.Probe,io.fabric8.openshift.api.model.monitoring.v1.ProbeBuilder>{
  public ProbeBuilder() {
    this(false);
  }
  public ProbeBuilder(java.lang.Boolean validationEnabled) {
    this(new Probe(), validationEnabled);
  }
  public ProbeBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeFluent<?> fluent) {
    this(fluent, false);
  }
  public ProbeBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Probe(), validationEnabled);
  }
  public ProbeBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Probe instance) {
    this(fluent, instance, false);
  }
  public ProbeBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Probe instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProbeBuilder(io.fabric8.openshift.api.model.monitoring.v1.Probe instance) {
    this(instance,false);
  }
  public ProbeBuilder(io.fabric8.openshift.api.model.monitoring.v1.Probe instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ProbeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.Probe build() {
    Probe buildable = new Probe(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProbeBuilder that = (ProbeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.3.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProbeBuilder extends ProbeFluentImpl<ProbeBuilder> implements VisitableBuilder<Probe,ProbeBuilder>{
  public ProbeBuilder() {
    this(false);
  }
  public ProbeBuilder(Boolean validationEnabled) {
    this(new Probe(), validationEnabled);
  }
  public ProbeBuilder(ProbeFluent<?> fluent) {
    this(fluent, false);
  }
  public ProbeBuilder(ProbeFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Probe(), validationEnabled);
  }
  public ProbeBuilder(ProbeFluent<?> fluent,Probe instance) {
    this(fluent, instance, false);
  }
  public ProbeBuilder(ProbeFluent<?> fluent,Probe instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProbeBuilder(Probe instance) {
    this(instance,false);
  }
  public ProbeBuilder(Probe instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProbeFluent<?> fluent;
  Boolean validationEnabled;
  public Probe build() {
    Probe buildable = new Probe(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
